@@ -9,14 +9,12 @@ import aiofiles
 import aiohttp
 from async_timeout import timeout
 
+from beniutils import makeFolder
 from beniutils.http import getHeaderByDefault
+from beniutils.log import warning
 
-from . import makeFolder
-from .log import warning
-
-_maxAsyncFileNum: int = 5000
+_maxAsyncFileNum: int = 50
 _currentAsyncFileNum: int = 0
-_waitAsyncFileTime: float = 0.5
 
 
 def setAsyncFileMaxNum(value: int):
@@ -41,12 +39,12 @@ async def asyncWriteFile(file: str, content: str, encoding: str = 'utf8', newlin
     makeFolder(os.path.dirname(file))
     global _currentAsyncFileNum
     while _currentAsyncFileNum > _maxAsyncFileNum:
-        await asyncio.sleep(_waitAsyncFileTime)
+        await asyncio.sleep(0)
     _currentAsyncFileNum += 1
     async with aiofiles.open(file, 'w', encoding=encoding, newline=newline) as f:
         await f.write(content)
-        await f.flush()
-        await f.close()
+        # await f.flush()
+        # await f.close()
     _currentAsyncFileNum -= 1
 
 
@@ -54,23 +52,23 @@ async def asyncWriteBinFile(file: str, data: bytes):
     makeFolder(os.path.dirname(file))
     global _currentAsyncFileNum
     while _currentAsyncFileNum > _maxAsyncFileNum:
-        await asyncio.sleep(_waitAsyncFileTime)
+        await asyncio.sleep(0)
     _currentAsyncFileNum += 1
     async with aiofiles.open(file, 'wb') as f:
         await f.write(data)
-        await f.flush()
-        await f.close()
+        # await f.flush()
+        # await f.close()
     _currentAsyncFileNum -= 1
 
 
 async def asyncReadFile(file: str, encoding: str = 'utf8', newline: str = '\n'):
     global _currentAsyncFileNum
     while _currentAsyncFileNum > _maxAsyncFileNum:
-        await asyncio.sleep(_waitAsyncFileTime)
+        await asyncio.sleep(0)
     _currentAsyncFileNum += 1
     async with aiofiles.open(file, 'r', encoding=encoding, newline=newline) as f:
         data = await f.read()
-        await f.close()
+        # await f.close()
     _currentAsyncFileNum -= 1
     return data
 
@@ -78,11 +76,11 @@ async def asyncReadFile(file: str, encoding: str = 'utf8', newline: str = '\n'):
 async def asyncReadBinFile(file: str):
     global _currentAsyncFileNum
     while _currentAsyncFileNum > _maxAsyncFileNum:
-        await asyncio.sleep(_waitAsyncFileTime)
+        await asyncio.sleep(0)
     _currentAsyncFileNum += 1
     async with aiofiles.open(file, 'rb') as f:
         data = await f.read()
-        await f.close()
+        # await f.close()
     _currentAsyncFileNum -= 1
     return data
 
