@@ -2,9 +2,10 @@ import os
 import sys
 import time
 from datetime import datetime as Datetime
+from datetime import timezone
 from typing import Optional
+from zoneinfo import ZoneInfo
 
-import pytz
 import typer
 from colorama import Fore
 
@@ -126,13 +127,13 @@ def taskBuild(
             remove(workspaceFolder)
 
 
-@app.command(
-    help="格式化时间戳",
-)
+@app.command()
 def timeshow(
     timestamp: Optional[float] = typer.Argument(None, help="时间戳，默认使用当前系统的时间戳", show_default=False),
 ):
-    timestamp = timestamp or time.time()
+    '''格式化时间戳'''
+    if timestamp is None:
+        timestamp = time.time()
     fmt = "%Y-%m-%d %H:%M:%S %z"
     print()
 
@@ -143,15 +144,30 @@ def timeshow(
     printColor(time.strftime(fmt, localtime), tzname, colorList=[Fore.LIGHTYELLOW_EX])
     print()
 
-    tzNameList = [
+    # pytz版本，留作参考别删除
+    # tzNameList = [
+    #     "Asia/Tokyo",
+    #     "Asia/Kolkata",
+    #     "Europe/London",
+    #     "America/New_York",
+    #     "America/Chicago",
+    #     "America/Los_Angeles",
+    # ]
+    # for tzName in tzNameList:
+    #     tz = pytz.timezone(tzName)
+    #     print(Datetime.fromtimestamp(timestamp, tz).strftime(fmt), tzName)
+
+    datetime_utc = Datetime.fromtimestamp(timestamp, tz=timezone.utc)
+    tzname_list = [
         "Asia/Tokyo",
         "Asia/Kolkata",
         "Europe/London",
         "America/New_York",
+        "America/Chicago",
         "America/Los_Angeles",
     ]
-    for tzName in tzNameList:
-        tz = pytz.timezone(tzName)
-        print(Datetime.fromtimestamp(timestamp, tz).strftime(fmt), tzName)
+    for tzname in tzname_list:
+        datetime_tz = datetime_utc.astimezone(ZoneInfo(tzname))
+        print(f"{datetime_tz} {tzname}")
 
     print()
